<template>
    <div class="system-add-menu-container">
        <el-dialog v-model="ifShowInspectTaskDialog" :title="title" width="60%">
            <el-form :model="inspectTaskForm" label-width="120px" ref="inspectTaskFormRef">
                <el-row>
                    <el-col :span="12" style="margin-bottom: 20px">
                        <el-form-item label="任务名称" prop="unitName">
                            <el-input v-model="inspectTaskForm.taskName" :disabled="!inspectPointConfirm" class="input-add" placeholder="请填写任务名称"> </el-input>
                        </el-form-item>
                    </el-col>
                    <el-col :span="12" style="margin-bottom: 20px">
                        <el-form-item label="任务类型" prop="taskType">
                            <el-select v-model="inspectTaskForm.taskType" :disabled="!inspectPointConfirm" class="input-add" placeholder="请选择任务类型">
                                <el-option v-for="item in workTypeList" :key="item.id" :value="item.id" :label="item.name"></el-option>
                            </el-select>
                        </el-form-item>
                    </el-col>
                    <el-col :span="12" style="margin-bottom: 20px">
                        <el-form-item label="巡检部门" prop="execDepId">
                            <el-cascader @change="giveClassGroup" :disabled="!inspectPointConfirm" :options="departmentList" :props="{ emitPath: false, checkStrictly: true, value: 'depId', label: 'depName' }" clearable filterable class="input-add" v-model="inspectTaskForm.execDepId"> </el-cascader>
                        </el-form-item>
                    </el-col>
                    <el-col :span="12" style="margin-bottom: 20px">
                        <el-form-item label="巡检班组" prop="execClassgroupId">
                            <el-select v-model="inspectTaskForm.execClassgroupId" :disabled="!inspectPointConfirm" class="input-add">
                                <el-option v-for="item in classGroup" :key="item.id" :value="item.id" :label="item.groupName"></el-option>
                            </el-select>
                        </el-form-item>
                    </el-col>
                    <el-col :span="12" style="margin-bottom: 20px">
                        <el-form-item label="巡检人" prop="execUserName">
                            <el-input v-model="inspectTaskForm.execUserName" :disabled="!inspectPointConfirm" class="input-add"> </el-input>
                        </el-form-item>
                    </el-col>
                    <el-col :span="12" style="margin-bottom: 20px">
                        <el-form-item label="任务开始时间" prop="startTime">
                            <el-date-picker v-model="inspectTaskForm.startTime" :disabled="!inspectPointConfirm" placeholder="请选择任务开始时间" type="datetime" format="YYYY/MM/DD HH:mm:ss" value-format="YYYY-MM-DD HH:mm:ss" class="input-add" />
                        </el-form-item>
                    </el-col>
                </el-row>

                <div class="checkUnit-point">
                    <el-tabs class="active" v-model="activeName">
                        <el-tab-pane label="巡检链" name="inspectChain">
                            <el-table :data="inspectTaskForm.points" fit style="width: 100%">
                                <el-table-column type="index" label="序号" />
                                <el-table-column prop="point" label="巡检点" show-overflow-tooltip align="center"></el-table-column>
                                <el-table-column prop="region" label="所属设备" show-overflow-tooltip align="center"></el-table-column>
                                <el-table-column prop="rfid" label="RFID" show-overflow-tooltip align="center"></el-table-column>
                                <el-table-column prop="quotaContent" label="指标作业" show-overflow-tooltip align="center"></el-table-column>
                                <el-table-column prop="secondReferenceResult" label="记录值" show-overflow-tooltip align="center">
                                    <template #default="scope">
                                        <div :style="{ color: scope.row.reportResult == 1 ? '#ff0000' : '#409eff' }">
                                            {{ scope.row.dataReportType == 1 ? '无' : scope.row.secondReferenceResult }}
                                        </div>
                                    </template>
                                </el-table-column>
                                <el-table-column prop="quotaUnit" label="指标单位" show-overflow-tooltip align="center"></el-table-column>
                                <el-table-column prop="reportResult" label="结果" show-overflow-tooltip align="center">
                                    <template #default="scope">
                                        <div :style="{ color: scope.row.reportResult == 1 ? '#ff0000' : '#409eff' }">
                                            {{ scope.row.reportResult == 0 ? '正常' : scope.row.reportResult == 1 ? '存在异常' : scope.row.reportResult == 2 ? '备' : '无' }}
                                        </div>
                                    </template>
                                </el-table-column>
                                <!--                                <el-table-column label="操作" width="150" align="center">-->
                                <!--                                    <template #default="scope">-->
                                <!--                                        <el-button size="small" text type="danger" @click="onDelCheckUnit(scope.$index, scope.row)">删除</el-button>-->
                                <!--                                    </template>-->
                                <!--                                </el-table-column>-->
                            </el-table>
                        </el-tab-pane>
                        <el-tab-pane label="统计数据" name="allData">
                            <sum-data :sumData="taskAndQuotas"></sum-data>
                        </el-tab-pane>
                    </el-tabs>
                </div>
                <div align="right" v-show="inspectPointConfirm">
                    <el-button type="warning" @click="inspectPointDialog = false" size="default" plain>取消</el-button>
                    <el-button type="primary" @click="submitInspectTask()" size="default">确认</el-button>
                </div>
            </el-form>
        </el-dialog>
    </div>
</template>

<script lang="ts">
import { toRefs, reactive, defineComponent, ref, onMounted, defineAsyncComponent } from 'vue';
import { RFIDApi } from '/@/api/intellectInspectSystem/RFID';
import { ElMessage } from 'element-plus/es';
import { inspectTaskApi } from '/@/api/intellectInspectSystem/inspectTask';
import { facilityAreaApi } from '/@/api/intellectInspectSystem/facilityAreaManage';
import { inspectRecordApi } from '/@/api/intellectInspectSystem/inspectRecord';
interface dataState {
    title: string;
    taskAndQuotas: [];
    pointTitle: string;
    activeName: string;
    inspectPointConfirm: boolean;
    inspectPointDialog: boolean;
    ifShowInspectTaskDialog: boolean;
    inspectPointForm: inspectPointForm;
    inspectTaskForm: {
        execClassgroupId: number | null;
        execDepId: number | null;
        id: number | null;
        execUserName: string;
        startTime: string | null;
        taskName: string | null;
        taskType: number | null;
        validTime: string | null;
        points: Array<inspectPointForm>;
    };
    workTypeList: [];
    departmentList: [];
    timeList: [];
    dataReportTypeList: Array<dataReport>;
    firstReferenceValueList: Array<dataReport>;
    secondReferenceSignList: Array<dataReport>;
    thirdReferenceSignList: Array<dataReport>;
    classGroupList: Array<classGroup>;
    classGroup: Array<classGroup>;
    quotaList: Array<quota>;
    inspectPointAllList: Array<inspectPointAllState>;
}
interface inspectPointAllState {
    id: number;
    code: string;
    regionId: number;
    rfidId: number;
}
interface classGroup {
    depId: number;
}
interface dataReport {
    id: number;
    name: string;
}
interface quota {
    id: number;
    type: string;
    unit: string;
}
interface inspectPointForm {
    id: number | null;
    unitId: number | null;
    unitUuid: string | null;
    pointId: number | null;
    pointUuid: string | null;
    regionId: number | null;
    regionUuid: string | null;
    rfidId: number | null;
    quotaId: number | null;
    quotaUnit: string | null;
    reportResult: number | null;
    secondReferenceResult: number | null;
    execSequence: number | null;
    dataReportType: number | null;
    firstReferenceValue: number | null;
    secondReferenceSign: number | null;
    secondReferenceValue: number | null;
    thirdReferenceSign: number | null;
    thirdReferenceValue: number | null;
}
export default defineComponent({
    name: 'inspectTaskDialog',
    components: {
        SumData: defineAsyncComponent(() => import('/@/views/intellectInspect/inspectIndex/components/sum.vue'))
    },
    setup(props: any, context: any) {
        const inspectTaskFormRef = ref();
        const data = reactive<dataState>({
            title: '',
            taskAndQuotas: [],
            pointTitle: '',
            activeName: 'inspectChain',
            inspectPointConfirm: false,
            inspectPointDialog: false,
            ifShowInspectTaskDialog: false,
            inspectPointForm: {
                id: null,
                unitId: null,
                unitUuid: null,
                pointId: null,
                pointUuid: null,
                regionId: null,
                regionUuid: null,
                rfidId: null,
                quotaId: null,
                quotaUnit: null,
                execSequence: null,
                secondReferenceResult: null,
                reportResult: null,
                dataReportType: null,
                firstReferenceValue: null,
                secondReferenceSign: null,
                secondReferenceValue: null,
                thirdReferenceSign: null,
                thirdReferenceValue: null
            },
            inspectTaskForm: {
                execClassgroupId: null,
                execDepId: null,
                id: null,
                points: [],
                execUserName: '',
                startTime: null,
                taskName: null,
                taskType: null,
                validTime: null
            },
            workTypeList: [],
            departmentList: [],
            timeList: [],
            classGroupList: [],
            classGroup: [],
            quotaList: [],
            inspectPointAllList: [],
            dataReportTypeList: [
                { id: 1, name: '选择' },
                { id: 2, name: '填空' },
                { id: 3, name: '选择并填空' }
            ],
            firstReferenceValueList: [
                { id: 0, name: '正常' },
                { id: 1, name: '存在异常' },
                { id: 2, name: '备' }
            ],
            secondReferenceSignList: [
                { id: 1, name: '>' },
                { id: 2, name: '>=' }
            ],
            thirdReferenceSignList: [
                { id: 3, name: '<' },
                { id: 4, name: '<=' }
            ]
        });

        const openInspectPointDialog = (type: string, item: {}) => {
            data.inspectPointDialog = true;
            if (type === '新增') {
                data.pointTitle = '新增巡检点';
                data.inspectPointForm = {
                    id: null,
                    unitId: null,
                    unitUuid: null,
                    pointId: null,
                    pointUuid: null,
                    regionId: null,
                    regionUuid: null,
                    rfidId: null,
                    quotaId: null,
                    quotaUnit: null,
                    reportResult: null,
                    execSequence: null,
                    secondReferenceResult: null,
                    dataReportType: null,
                    firstReferenceValue: null,
                    secondReferenceSign: null,
                    secondReferenceValue: null,
                    thirdReferenceSign: null,
                    thirdReferenceValue: null
                };
            } else {
                data.pointTitle = '修改巡检点';
                data.inspectPointForm = JSON.parse(JSON.stringify(item));
            }
        };

        const showInspectRecordDialog = (type: string, item: { id: number; uuid: string; execUserName: string }, workTypeList: [], department: [], timeType: [], classGroupList: [], quotaList: [], inspectPointAllList: []) => {
            data.quotaList = JSON.parse(JSON.stringify(quotaList));
            data.timeList = JSON.parse(JSON.stringify(timeType));
            data.inspectPointAllList = JSON.parse(JSON.stringify(inspectPointAllList));
            data.workTypeList = JSON.parse(JSON.stringify(workTypeList));
            data.departmentList = JSON.parse(JSON.stringify(department));
            data.classGroupList = JSON.parse(JSON.stringify(classGroupList));
            data.ifShowInspectTaskDialog = true;
            data.inspectPointConfirm = false;
            data.title = '查看巡检记录';
            getSum(item.id);
            inspectRecordApi()
                .getInspectRecordById({ id: item.id, uuid: item.uuid })
                .then((res) => {
                    if (res.data.code === '200') {
                        data.inspectTaskForm.execDepId = res.data.data.execDepId;
                        giveClassGroup();
                        data.inspectTaskForm = JSON.parse(JSON.stringify(res.data.data));
                        data.inspectTaskForm.execUserName = item.execUserName;
                    } else {
                    }
                })
                .catch((error) => {});
        };

        // 格式化表格数据
        // const toRefer =(row, column, cellValue, index)=>{
        //     return row.secondReferenceResult==0?'正常':(row.reportResult==1?'异常':'无')
        // }

        const getSum = async (id: number) => {
            let res = await inspectRecordApi().getInspectRecordSum({ id: id });
            if (res.data.code === '200') {
                data.taskAndQuotas = JSON.parse(JSON.stringify(res.data.data.taskAndQuotas));
                console.log(data.taskAndQuotas, '666666666666');
            } else {
                ElMessage({
                    type: 'warning',
                    message: res.data.msg
                });
            }
        };

        const submitInspectPoint = async () => {
            if (data.title === '新增巡检任务' && data.pointTitle === '新增巡检点') {
                if (data.inspectTaskForm.points.length === 0) {
                    data.inspectPointForm.execSequence = 1;
                } else {
                    data.inspectPointForm.execSequence = (data.inspectTaskForm.points[data.inspectTaskForm.points.length - 1].execSequence as number) + 1;
                }
                data.inspectTaskForm.points.push(data.inspectPointForm);
                data.inspectPointDialog = false;
            } else if (data.title === '新增巡检任务' && data.pointTitle === '修改巡检点') {
                let result = data.inspectTaskForm.points.findIndex((item) => item.id === data.inspectPointForm.id);
                data.inspectTaskForm.points[result] = data.inspectPointForm;
                data.inspectPointDialog = false;
            } else if (data.title === '修改巡检任务' && data.pointTitle === '新增巡检点') {
                data.inspectPointForm.unitId = data.inspectTaskForm.id;
                if (data.inspectTaskForm.points.length === 0) {
                    data.inspectPointForm.execSequence = 1;
                } else {
                    data.inspectPointForm.execSequence = (data.inspectTaskForm.points[data.inspectTaskForm.points.length - 1].execSequence as number) + 1;
                }
                let res = await inspectTaskApi().addChainOfInspectTask(data.inspectPointForm);
                if (res.data.code === '200') {
                    ElMessage({
                        type: 'success',
                        message: '巡检点新增成功',
                        duration: 2000
                    });
                    data.inspectPointDialog = false;
                    data.inspectTaskForm.points.push(data.inspectPointForm);
                } else {
                    ElMessage({
                        type: 'warning',
                        message: res.data.msg
                    });
                }
            } else {
                data.inspectPointForm.unitId = data.inspectTaskForm.id;
                let res = await inspectTaskApi().modChainOfInspectTask(data.inspectPointForm);
                if (res.data.code === '200') {
                    ElMessage({
                        type: 'success',
                        message: '巡检点修改成功',
                        duration: 2000
                    });
                    let result = data.inspectTaskForm.points.findIndex((item) => item.id === data.inspectPointForm.id);
                    data.inspectTaskForm.points[result] = data.inspectPointForm;
                    data.inspectPointDialog = false;
                } else {
                    ElMessage({
                        type: 'warning',
                        message: res.data.msg
                    });
                }
            }
        };
        const deleteFlow = async (index: number, item: { id: number }) => {
            if (data.pointTitle === '新增巡检点') {
                data.inspectTaskForm.points.splice(index, 1);
            } else {
                let res = await inspectTaskApi().deleteChainOfInspectTask({ id: item.id, unitId: data.inspectTaskForm.id });
                if (res.data.code === '200') {
                    data.inspectTaskForm.points.splice(index, 1);
                    ElMessage({
                        type: 'success',
                        message: '巡检点删除成功'
                    });
                } else {
                    ElMessage({
                        type: 'warning',
                        message: res.data.msg
                    });
                }
            }
        };

        const giveRegionAndRFID = () => {
            data.inspectPointForm.regionId = data.inspectPointAllList.find((item) => item.id === data.inspectPointForm.pointId)?.regionId as number;
            data.inspectPointForm.rfidId = data.inspectPointAllList.find((item) => item.id === data.inspectPointForm.pointId)?.rfidId as number;
        };

        const giveClassGroup = () => {
            data.inspectTaskForm.execClassgroupId = null;
            data.classGroup = data.classGroupList.filter((item) => item.depId === data.inspectTaskForm.execDepId);
        };

        const giveQuotaUnit = () => {
            data.inspectPointForm.quotaUnit = data.quotaList.find((item) => item.id === data.inspectPointForm.quotaId)?.unit as string;
        };
        const submitInspectTask = () => {
            inspectTaskFormRef.value.validate(async (valid: Boolean) => {
                if (valid) {
                    if (data.title === '新增巡检任务') {
                        let res = await inspectTaskApi().addInspectTask(data.inspectTaskForm);
                        if (res.data.code === '200') {
                            ElMessage({
                                type: 'success',
                                message: '巡检任务新增成功',
                                duration: 2000
                            });
                            data.ifShowInspectTaskDialog = false;
                            context.emit('refreshInspectTask');
                        } else {
                            ElMessage({
                                type: 'warning',
                                message: res.data.msg
                            });
                        }
                    } else {
                        let res = await inspectTaskApi().modInspectTask(data.inspectTaskForm);
                        if (res.data.code === '200') {
                            ElMessage({
                                type: 'success',
                                message: '巡检指标修改成功',
                                duration: 2000
                            });
                            data.ifShowInspectTaskDialog = false;
                            context.emit('refreshInspectTask');
                        } else {
                            ElMessage({
                                type: 'warning',
                                message: res.data.msg
                            });
                        }
                    }
                } else {
                    ElMessage({
                        type: 'warning',
                        message: '请完善基本信息'
                    });
                }
            });
        };

        return {
            ...toRefs(data),
            inspectTaskFormRef,
            deleteFlow,
            getSum,
            // toRefer,
            giveQuotaUnit,
            giveClassGroup,
            submitInspectTask,
            submitInspectPoint,
            giveRegionAndRFID,
            showInspectRecordDialog,
            openInspectPointDialog
        };
    }
});
</script>

<style scoped lang="scss">
$homeNavLengh: 8;
.home-container {
    height: calc(100vh - 144px);
    box-sizing: border-box;
    overflow: hidden;
    .homeCard {
        width: 100%;
        padding: 20px;
        box-sizing: border-box;
        background: #fff;
        border-radius: 4px;

        .main-card {
            width: 100%;
            height: 100%;
            .cardTop {
                display: flex;
                align-items: center;
                justify-content: space-between;
                margin-bottom: 20px;
                .mainCardBtn {
                    margin: 0;
                }
            }
            .pageBtn {
                height: 60px;
                display: flex;
                align-items: center;
                justify-content: right;

                .demo-pagination-block + .demo-pagination-block {
                    margin-top: 10px;
                }
                .demo-pagination-block .demonstration {
                    margin-bottom: 16px;
                }
            }
        }
        &:last-of-type {
            height: calc(100% - 100px);
        }
    }
    .el-row {
        display: flex;
        align-items: center;
        margin-bottom: 20px;
        &:last-child {
            margin-bottom: 0;
        }
        .grid-content {
            align-items: center;
            min-height: 36px;
        }

        .topInfo {
            display: flex;
            align-items: center;
            font-size: 16px;
            font-weight: bold;

            & > div {
                white-space: nowrap;
                margin-right: 20px;
            }
        }
    }
}
.stepItem {
    width: 100%;
    display: flex;
    align-items: flex-start;
    margin-bottom: 30px;
    margin-left: 30px;
    padding-bottom: 30px;
    border-left: 2px solid #ccc;
    &:first-of-type {
        margin-top: 30px;
    }
    &:last-of-type {
        margin-bottom: 0;
        border-left: none;
    }
    .stepNum {
        width: 30px;
        height: 30px;
        border-radius: 15px;
        box-sizing: border-box;
        color: #333;
        border: 1px solid #999;
        line-height: 28px;
        text-align: center;
        margin-right: 10px;
        margin-left: -16px;
        margin-top: -30px;
    }
    .stepCard {
        width: 100%;
        margin-top: -30px;

        .box-card {
            width: 100%;
            &:deep(.el-card__header) {
                padding: 10px 15px;
            }
            .card-header {
                width: 100%;
                display: flex;
                justify-content: space-between;
                align-items: center;
                & > div:first-of-type {
                    margin-right: 80px;
                    font-size: 18px;
                    font-weight: bold;
                }
            }
        }
    }
    &:hover .card-header {
        color: #0098f5;
    }
    &:hover .stepNum {
        border: 2px solid #0098f5;
        color: #0098f5;
    }
}
:deep(.el-date-editor) {
    width: 100%;
}
</style>
